1 new commit in galaxy-central:
https://bitbucket.org/galaxy/galaxy-central/commits/f199b236ceb0/
changeset: f199b236ceb0
user: inithello
date: 2013-01-16 21:14:36
summary: Fix missing import that was breaking unit tests.
affected #: 1 file
diff -r 3a2211dc42f15e0bd357de6abb7dca73221854c7 -r f199b236ceb08e9588351223b6277861e9f87325 lib/galaxy/datatypes/tabular.py
--- a/lib/galaxy/datatypes/tabular.py
+++ b/lib/galaxy/datatypes/tabular.py
@@ -13,7 +13,7 @@
from galaxy.datatypes import metadata
from galaxy.datatypes.checkers import is_gzip
from galaxy.datatypes.metadata import MetadataElement
-from galaxy.datatypes.sniff import get_headers
+from galaxy.datatypes.sniff import get_headers, get_test_fname
from galaxy.util.json import to_json_string
log = logging.getLogger(__name__)
Repository URL: https://bitbucket.org/galaxy/galaxy-central/
--
This is a commit notification from bitbucket.org. You are receiving
this because you have the service enabled, addressing the recipient of
this email.
2 new commits in galaxy-central:
https://bitbucket.org/galaxy/galaxy-central/commits/5e710a6f1c99/
changeset: 5e710a6f1c99
user: inithello
date: 2013-01-16 18:35:36
summary: Fix for removing roles from users in the tool shed.
affected #: 1 file
diff -r 4f01c6a8693e855da6abad43112afe7447da6e82 -r 5e710a6f1c99e56abb5eb7964cd1c673526866b2 lib/galaxy/web/base/controllers/admin.py
--- a/lib/galaxy/web/base/controllers/admin.py
+++ b/lib/galaxy/web/base/controllers/admin.py
@@ -224,19 +224,20 @@
role = get_role( trans, id )
if params.get( 'role_members_edit_button', False ):
in_users = [ trans.sa_session.query( trans.app.model.User ).get( x ) for x in util.listify( params.in_users ) ]
- for ura in role.users:
- user = trans.sa_session.query( trans.app.model.User ).get( ura.user_id )
- if user not in in_users:
- # Delete DefaultUserPermissions for previously associated users that have been removed from the role
- for dup in user.default_permissions:
- if role == dup.role:
- trans.sa_session.delete( dup )
- # Delete DefaultHistoryPermissions for previously associated users that have been removed from the role
- for history in user.histories:
- for dhp in history.default_permissions:
- if role == dhp.role:
- trans.sa_session.delete( dhp )
- trans.sa_session.flush()
+ if trans.webapp.name == 'galaxy':
+ for ura in role.users:
+ user = trans.sa_session.query( trans.app.model.User ).get( ura.user_id )
+ if user not in in_users:
+ # Delete DefaultUserPermissions for previously associated users that have been removed from the role
+ for dup in user.default_permissions:
+ if role == dup.role:
+ trans.sa_session.delete( dup )
+ # Delete DefaultHistoryPermissions for previously associated users that have been removed from the role
+ for history in user.histories:
+ for dhp in history.default_permissions:
+ if role == dhp.role:
+ trans.sa_session.delete( dhp )
+ trans.sa_session.flush()
in_groups = [ trans.sa_session.query( trans.app.model.Group ).get( x ) for x in util.listify( params.in_groups ) ]
trans.app.security_agent.set_entity_role_associations( roles=[ role ], users=in_users, groups=in_groups )
trans.sa_session.refresh( role )
https://bitbucket.org/galaxy/galaxy-central/commits/974d7c41b8df/
changeset: 974d7c41b8df
user: inithello
date: 2013-01-16 18:36:19
summary: Fix server error when trying to create a component review for a repository when one already exists for that changeset revision.
affected #: 1 file
diff -r 5e710a6f1c99e56abb5eb7964cd1c673526866b2 -r 974d7c41b8dfb7e77c6dfa24da05b31d684fd2e6 lib/galaxy/webapps/community/controllers/repository_review.py
--- a/lib/galaxy/webapps/community/controllers/repository_review.py
+++ b/lib/galaxy/webapps/community/controllers/repository_review.py
@@ -377,6 +377,7 @@
if repository_id:
if changeset_revision:
# Make sure there is not already a review of the revision by the user.
+ repository = suc.get_repository_in_tool_shed( trans, repository_id )
if common.get_review_by_repository_id_changeset_revision_user_id( trans=trans,
repository_id=repository_id,
changeset_revision=changeset_revision,
@@ -384,7 +385,6 @@
message = "You have already created a review for revision <b>%s</b> of repository <b>%s</b>." % ( changeset_revision, repository.name )
status = "error"
else:
- repository = suc.get_repository_in_tool_shed( trans, repository_id )
# See if there are any reviews for previous changeset revisions that the user can copy.
if not create_without_copying and not previous_review_id and common.has_previous_repository_reviews( trans, repository, changeset_revision ):
return trans.response.send_redirect( web.url_for( controller='repository_review',
Repository URL: https://bitbucket.org/galaxy/galaxy-central/
--
This is a commit notification from bitbucket.org. You are receiving
this because you have the service enabled, addressing the recipient of
this email.
1 new commit in galaxy-central:
https://bitbucket.org/galaxy/galaxy-central/commits/4f01c6a8693e/
changeset: 4f01c6a8693e
user: natefoo
date: 2013-01-16 18:30:24
summary: Remove spurious debugging statement.
affected #: 1 file
diff -r ee6ddbd3fcb35845239ea82c9062c4893e88c37e -r 4f01c6a8693e855da6abad43112afe7447da6e82 lib/galaxy/web/framework/__init__.py
--- a/lib/galaxy/web/framework/__init__.py
+++ b/lib/galaxy/web/framework/__init__.py
@@ -274,7 +274,6 @@
from galaxy.web.base.controller import ControllerUnavailable
package = import_module( package_name )
controller_dir = package.__path__[0]
- print ">>>", controller_dir, package.__path__
for fname in os.listdir( controller_dir ):
if not( fname.startswith( "_" ) ) and fname.endswith( ".py" ):
name = fname[:-3]
Repository URL: https://bitbucket.org/galaxy/galaxy-central/
--
This is a commit notification from bitbucket.org. You are receiving
this because you have the service enabled, addressing the recipient of
this email.
1 new commit in galaxy-central:
https://bitbucket.org/galaxy/galaxy-central/commits/ee6ddbd3fcb3/
changeset: ee6ddbd3fcb3
user: jgoecks
date: 2013-01-15 23:17:32
summary: Update history functional tests for changes in f93113b
affected #: 2 files
diff -r 06cdf8b0b582c40fa89fc7e398fecacb3943dbfc -r ee6ddbd3fcb35845239ea82c9062c4893e88c37e test/base/twilltestcase.py
--- a/test/base/twilltestcase.py
+++ b/test/base/twilltestcase.py
@@ -417,7 +417,7 @@
if active_datasets:
self.check_page_for_string( 'Create</a> a new empty history' )
self.check_page_for_string( 'Construct workflow</a> from current history' )
- self.check_page_for_string( 'Clone</a> current history' )
+ self.check_page_for_string( 'Copy</a> current history' )
self.check_page_for_string( 'Share</a> current history' )
self.check_page_for_string( 'Change default permissions</a> for current history' )
if histories_shared_by_others:
@@ -534,13 +534,13 @@
for check_str in strings_displayed:
self.check_page_for_string( check_str )
self.home()
- def clone_history( self, history_id, clone_choice, strings_displayed=[], strings_displayed_after_submit=[] ):
+ def copy_history( self, history_id, copy_choice, strings_displayed=[], strings_displayed_after_submit=[] ):
self.home()
- self.visit_page( "history/clone?id=%s" % history_id )
+ self.visit_page( "history/copy?id=%s" % history_id )
for check_str in strings_displayed:
self.check_page_for_string( check_str )
- tc.fv( '1', 'clone_choice', clone_choice )
- tc.submit( 'clone_choice_button' )
+ tc.fv( '1', 'copy_choice', copy_choice )
+ tc.submit( 'copy_choice_button' )
for check_str in strings_displayed_after_submit:
self.check_page_for_string( check_str )
self.home()
--
This is a commit notification from bitbucket.org. You are receiving
this because you have the service enabled, addressing the recipient of
this email.
1 new commit in galaxy-central:
https://bitbucket.org/galaxy/galaxy-central/commits/4bd419751ed3/
changeset: 4bd419751ed3
user: dan
date: 2013-01-15 22:46:47
summary: Make galaxy.tools.Tool a new-style class.
affected #: 1 file
diff -r 52395842f8e65a6484268d3db1e3dbac09d60089 -r 4bd419751ed3e8cc54913fa37389111a0e7faaa9 lib/galaxy/tools/__init__.py
--- a/lib/galaxy/tools/__init__.py
+++ b/lib/galaxy/tools/__init__.py
@@ -813,7 +813,7 @@
self.attributes['split_size'] = 20
self.attributes['split_mode'] = 'number_of_parts'
-class Tool:
+class Tool( object ):
"""
Represents a computational tool that can be executed through Galaxy.
"""
Repository URL: https://bitbucket.org/galaxy/galaxy-central/
diff -r ec543816a2a2b6fea98e3353e65f9e9c30d62cbe -r f93113b8e4771c31aed6dd39aba38d09e11ffb31 templates/history/clone.mako
--- a/templates/history/clone.mako
+++ /dev/null
@@ -1,27 +0,0 @@
-<% _=n_ %>
-<%inherit file="/base.mako"/>
-<%def name="title()">Clone History</%def>
-
-<div class="toolForm">
- <div class="toolFormTitle">Clone History</div>
- <div class="toolFormBody">
- <form action="${h.url_for( controller='history', action='clone' )}" method="post" >
- <div class="form-row">
- %if id_argument is not None:
- <input type="hidden" name="id" value="${id_argument}">
- %endif
- You can clone the history such that the clone will include all items in the original
- history, or you can eliminate the original history's deleted items from the clone.
- </div>
- <div class="form-row">
- <input type="radio" name="clone_choice" value="activatable"> Clone all history items, including deleted items
- </div>
- <div class="form-row">
- <input type="radio" name="clone_choice" value="active"> Clone only items that are not deleted
- </div>
- <div class="form-row">
- <input type="submit" name="clone_choice_button" value="Clone">
- </div>
- </form>
- </div>
-</div>
diff -r ec543816a2a2b6fea98e3353e65f9e9c30d62cbe -r f93113b8e4771c31aed6dd39aba38d09e11ffb31 templates/history/copy.mako
--- /dev/null
+++ b/templates/history/copy.mako
@@ -0,0 +1,27 @@
+<% _=n_ %>
+<%inherit file="/base.mako"/>
+<%def name="title()">Copy History</%def>
+
+<div class="toolForm">
+ <div class="toolFormTitle">Copy History</div>
+ <div class="toolFormBody">
+ <form action="${h.url_for( controller='history', action='copy' )}" method="post" >
+ <div class="form-row">
+ %if id_argument is not None:
+ <input type="hidden" name="id" value="${id_argument}">
+ %endif
+ You can make a copy of the history that includes all datasets in the original history or just the active
+ (not deleted) datasets.
+ </div>
+ <div class="form-row">
+ <input type="radio" name="copy_choice" value="activatable"> Copy all datasets, including deleted ones
+ </div>
+ <div class="form-row">
+ <input type="radio" name="copy_choice" value="active"> Copy only active (not deleted) datasets
+ </div>
+ <div class="form-row">
+ <input type="submit" name="copy_choice_button" value="Copy">
+ </div>
+ </form>
+ </div>
+</div>
diff -r ec543816a2a2b6fea98e3353e65f9e9c30d62cbe -r f93113b8e4771c31aed6dd39aba38d09e11ffb31 templates/history/options.mako
--- a/templates/history/options.mako
+++ b/templates/history/options.mako
@@ -16,7 +16,7 @@
%if len( history.active_datasets ) > 0:
<li><a href="${h.url_for( controller='root', action='history_new' )}">Create</a> a new empty history</li><li><a href="${h.url_for( controller='workflow', action='build_from_current_history' )}">Construct workflow</a> from current history</li>
- <li><a href="${h.url_for( controller='history', action='clone', id=trans.security.encode_id( history.id ) )}">Clone</a> current history</li>
+ <li><a href="${h.url_for( controller='history', action='copy', id=trans.security.encode_id( history.id ) )}">Copy</a> current history</li>
%endif
<li><a href="${h.url_for( controller='history', action='share' )}" target="galaxy_main">Share</a> current history</div><li><a href="${h.url_for( controller='root', action='history_set_default_permissions' )}">Change default permissions</a> for current history</li>
diff -r ec543816a2a2b6fea98e3353e65f9e9c30d62cbe -r f93113b8e4771c31aed6dd39aba38d09e11ffb31 templates/root/index.mako
--- a/templates/root/index.mako
+++ b/templates/root/index.mako
@@ -22,8 +22,8 @@
"${_("Create New")}": function() {
galaxy_history.location = "${h.url_for( controller='root', action='history_new' )}";
},
- "${_("Clone")}": function() {
- galaxy_main.location = "${h.url_for( controller='history', action='clone')}";
+ "${_("Copy History")}": function() {
+ galaxy_main.location = "${h.url_for( controller='history', action='copy')}";
},
"${_("Copy Datasets")}": function() {
galaxy_main.location = "${h.url_for( controller='dataset', action='copy_datasets' )}";
Repository URL: https://bitbucket.org/galaxy/galaxy-central/
--
This is a commit notification from bitbucket.org. You are receiving
this because you have the service enabled, addressing the recipient of
this email.
1 new commit in galaxy-central:
https://bitbucket.org/galaxy/galaxy-central/commits/ec543816a2a2/
changeset: ec543816a2a2
user: dannon
date: 2013-01-15 16:34:58
summary: page controller: fix invalid error syntax, remove unused import.
affected #: 1 file
diff -r 8d2fe975c13c33439167903653c6c06217cab764 -r ec543816a2a2b6fea98e3353e65f9e9c30d62cbe lib/galaxy/webapps/galaxy/controllers/page.py
--- a/lib/galaxy/webapps/galaxy/controllers/page.py
+++ b/lib/galaxy/webapps/galaxy/controllers/page.py
@@ -6,7 +6,6 @@
from galaxy.web.framework.helpers import time_ago, grids
from galaxy import util
from galaxy.util.sanitize_html import sanitize_html, _BaseHTMLProcessor
-from galaxy.util.odict import odict
from galaxy.util.json import from_json_string
def format_bool( b ):
@@ -716,7 +715,7 @@
id = trans.security.decode_id( id )
page = trans.sa_session.query( model.Page ).get( id )
if not page:
- err+msg( "Page not found" )
+ error( "Page not found" )
else:
return self.security_check( trans, page, check_ownership, check_accessible )
Repository URL: https://bitbucket.org/galaxy/galaxy-central/
diff -r 06cdf8b0b582c40fa89fc7e398fecacb3943dbfc -r ee6ddbd3fcb35845239ea82c9062c4893e88c37e test/functional/test_history_functions.py
--- a/test/functional/test_history_functions.py
+++ b/test/functional/test_history_functions.py
@@ -215,7 +215,7 @@
# Logged in as admin_user
self.delete_current_history( strings_displayed=[ "History (%s) has been shared with others, unshare it before deleting it." % history3.name ] )
def test_030_clone_shared_history( self ):
- """Testing cloning a shared history"""
+ """Testing copying a shared history"""
# logged in as admin user
self.logout()
self.login( email=regular_user1.email )
@@ -223,9 +223,9 @@
self.history_options( user=True, histories_shared_by_others=True )
# Shared history3 should be in regular_user1's list of shared histories
self.view_shared_histories( strings_displayed=[ history3.name, admin_user.email ] )
- self.clone_history( self.security.encode_id( history3.id ),
+ self.copy_history( self.security.encode_id( history3.id ),
'activatable',
- strings_displayed_after_submit=[ 'is now included in your previously stored histories.' ] )
+ strings_displayed_after_submit=[ 'has been created.' ] )
global history3_clone1
history3_clone1 = sa_session.query( galaxy.model.History ) \
.filter( and_( galaxy.model.History.table.c.deleted==False,
@@ -234,11 +234,11 @@
.first()
assert history3_clone1 is not None, "Problem retrieving history3_clone1 from database"
# Check list of histories to make sure shared history3 was cloned
- strings_displayed=[ "Clone of '%s' shared by '%s'" % ( history3.name, admin_user.email ) ]
+ strings_displayed=[ "Copy of '%s' shared by '%s'" % ( history3.name, admin_user.email ) ]
self.view_stored_active_histories( strings_displayed=strings_displayed )
def test_035_clone_current_history( self ):
- """Testing cloning the current history"""
+ """Testing copying the current history"""
# logged in as regular_user1
self.logout()
self.login( email=admin_user.email )
@@ -264,9 +264,9 @@
self.delete_history_item( str( hda_3_bed.id ) )
# Test cloning activatable datasets
- self.clone_history( self.security.encode_id( history3.id ),
+ self.copy_history( self.security.encode_id( history3.id ),
'activatable',
- strings_displayed_after_submit=['is now included in your previously stored histories.' ] )
+ strings_displayed_after_submit=['has been created.' ] )
global history3_clone2
history3_clone2 = sa_session.query( galaxy.model.History ) \
.filter( and_( galaxy.model.History.table.c.deleted==False,
@@ -276,7 +276,7 @@
assert history3_clone2 is not None, "Problem retrieving history3_clone2 from database"
# Check list of histories to make sure shared history3 was cloned
- self.view_stored_active_histories( strings_displayed=[ "Clone of '%s'" % history3.name ] )
+ self.view_stored_active_histories( strings_displayed=[ "Copy of '%s'" % history3.name ] )
# Switch to the cloned history to make sure activatable datasets were cloned
self.switch_history( id=self.security.encode_id( history3_clone2.id ), name=history3_clone2.name )
hda_2_bed = (
@@ -301,10 +301,10 @@
self.check_history_for_exact_string( self.security.encode_id( hda_3_bed.id ), show_deleted=True )
# Test cloning only active datasets
- self.clone_history(
+ self.copy_history(
self.security.encode_id( history3.id ),
'active',
- strings_displayed_after_submit=[ 'is now included in your previously stored histories.' ] )
+ strings_displayed_after_submit=[ 'has been created.' ] )
global history3_clone3
history3_clone3 = (
sa_session.query( galaxy.model.History )
@@ -316,7 +316,7 @@
assert history3_clone3 is not None, "Problem retrieving history3_clone3 from database"
# Check list of histories to make sure shared history3 was cloned
- self.view_stored_active_histories( strings_displayed = ["Clone of '%s'" % history3.name ] )
+ self.view_stored_active_histories( strings_displayed = ["Copy of '%s'" % history3.name ] )
# Switch to the cloned history to make sure ONLY activatable datasets were cloned
self.switch_history( id=self.security.encode_id( history3_clone3.id ) )
@@ -428,9 +428,9 @@
# Shared history5 should be in regular_user1's list of shared histories
self.view_shared_histories( strings_displayed=[ history5.name, admin_user.email ] )
# Clone restricted history5
- self.clone_history( self.security.encode_id( history5.id ),
+ self.copy_history( self.security.encode_id( history5.id ),
'activatable',
- strings_displayed_after_submit=[ 'is now included in your previously stored histories.' ] )
+ strings_displayed_after_submit=[ 'has been created.' ] )
global history5_clone1
history5_clone1 = sa_session.query( galaxy.model.History ) \
.filter( and_( galaxy.model.History.table.c.deleted==False,
@@ -439,7 +439,7 @@
.first()
assert history5_clone1 is not None, "Problem retrieving history5_clone1 from database"
# Check list of histories to make sure shared history5 was cloned
- self.view_stored_active_histories( strings_displayed=[ "Clone of '%s'" % history5.name ] )
+ self.view_stored_active_histories( strings_displayed=[ "Copy of '%s'" % history5.name ] )
# Make sure the dataset is accessible
self.switch_history( id=self.security.encode_id( history5_clone1.id ), name=history5_clone1.name )
self.check_history_for_string( 'chr1' )
@@ -486,9 +486,9 @@
# Shared history5 should be in regular_user2's list of shared histories
self.view_shared_histories( strings_displayed=[ history5.name, admin_user.email ] )
# Clone restricted history5
- self.clone_history( self.security.encode_id( history5.id ),
+ self.copy_history( self.security.encode_id( history5.id ),
'activatable',
- strings_displayed_after_submit=[ 'is now included in your previously stored histories.' ] )
+ strings_displayed_after_submit=[ 'has been created.' ] )
global history5_clone2
history5_clone2 = sa_session.query( galaxy.model.History ) \
.filter( and_( galaxy.model.History.table.c.deleted==False,
@@ -497,7 +497,7 @@
.first()
assert history5_clone2 is not None, "Problem retrieving history5_clone2 from database"
# Check list of histories to make sure shared history3 was cloned
- self.view_stored_active_histories( strings_displayed=[ "Clone of '%s'" % history5.name ] )
+ self.view_stored_active_histories( strings_displayed=[ "Copy of '%s'" % history5.name ] )
# Make sure the dataset is accessible
self.switch_history( id=self.security.encode_id( history5_clone2.id ), name=history5_clone2.name )
# Make sure both datasets are in the history
@@ -557,15 +557,15 @@
self.share_current_history( email,
strings_displayed_after_submit=strings_displayed_after_submit,
action='share_anyway' )
# Check security on clone of history5 for regular_user2
self.logout()
self.login( email=regular_user2.email )
# Shared history5 should be in regular_user2's list of shared histories
self.view_shared_histories( strings_displayed=[ history5.name, admin_user.email ] )
# Clone restricted history5
- self.clone_history( self.security.encode_id( history5.id ),
+ self.copy_history( self.security.encode_id( history5.id ),
'activatable',
- strings_displayed_after_submit=[ 'is now included in your previously stored histories.' ] )
+ strings_displayed_after_submit=[ 'has been created.' ] )
global history5_clone3
history5_clone3 = (
sa_session.query( galaxy.model.History )
@@ -576,7 +576,7 @@
assert history5_clone3 is not None, "Problem retrieving history5_clone3 from database"
# Check list of histories to make sure shared history3 was cloned
- self.view_stored_active_histories( strings_displayed=[ "Clone of '%s'" % history5.name ] )
+ self.view_stored_active_histories( strings_displayed=[ "Copy of '%s'" % history5.name ] )
# Make sure the dataset is accessible
self.switch_history( id=self.security.encode_id( history5_clone3.id ), name=history5_clone3.name )
# Make sure both datasets are in the history
@@ -602,16 +602,16 @@
self.display_history_item( str( hda_2_bed.id ), strings_displayed=[ 'chr1' ] )
# Delete the clone so the next test will be valid
self.delete_history( id=self.security.encode_id( history5_clone3.id ) )
# Check security on clone of history5 for regular_user3
self.logout()
self.login( email=regular_user3.email )
# Shared history5 should be in regular_user2's list of shared histories
self.view_shared_histories( strings_displayed=[ history5.name, admin_user.email ] )
# Clone restricted history5
- self.clone_history( self.security.encode_id( history5.id ),
+ self.copy_history( self.security.encode_id( history5.id ),
'activatable',
- strings_displayed_after_submit=[ 'is now included in your previously stored histories.' ] )
+ strings_displayed_after_submit=[ 'has been created.' ] )
global history5_clone4
history5_clone4 = (
sa_session.query( galaxy.model.History )
@@ -622,7 +622,7 @@
assert history5_clone4 is not None, "Problem retrieving history5_clone4 from database"
# Check list of histories to make sure shared history3 was cloned
- self.view_stored_active_histories( strings_displayed=[ "Clone of '%s'" % history5.name ] )
+ self.view_stored_active_histories( strings_displayed=[ "Copy of '%s'" % history5.name ] )
# Make sure the dataset is accessible
self.switch_history( id=self.security.encode_id( history5_clone4.id ), name=history5_clone4.name )
# Make sure both datasets are in the history
@@ -557,15 +557,15 @@
strings_displayed_after_submit=strings_displayed_after_submit,
action='share_anyway' )
- # Check security on clone of history5 for regular_user2
+ # Check security on copy of history5 for regular_user2
self.logout()
self.login( email=regular_user2.email )
@@ -602,16 +602,16 @@
# Delete the clone so the next test will be valid
self.delete_history( id=self.security.encode_id( history5_clone3.id ) )
- # Check security on clone of history5 for regular_user3
+ # Check security on copy of history5 for regular_user3
self.logout()
self.login( email=regular_user3.email )
Repository URL: https://bitbucket.org/galaxy/galaxy-central/
--
This is a commit notification from bitbucket.org. You are receiving
this because you have the service enabled, addressing the recipient of
this email.
1 new commit in galaxy-central:
https://bitbucket.org/galaxy/galaxy-central/commits/f93113b8e477/
changeset: f93113b8e477
user: jgoecks
date: 2013-01-15 16:48:35
summary: Change 'clone history' to 'copy history' in user interface and associated code.
affected #: 5 files
diff -r ec543816a2a2b6fea98e3353e65f9e9c30d62cbe -r f93113b8e4771c31aed6dd39aba38d09e11ffb31 lib/galaxy/webapps/galaxy/controllers/history.py
--- a/lib/galaxy/webapps/galaxy/controllers/history.py
+++ b/lib/galaxy/webapps/galaxy/controllers/history.py
@@ -150,7 +150,7 @@
]
operations = [
grids.GridOperation( "View", allow_multiple=False, target="_top" ),
- grids.GridOperation( "Clone" ),
+ grids.GridOperation( "Copy" ),
grids.GridOperation( "Unshare" )
]
standard_filters = []
@@ -400,13 +400,13 @@
# Display history.
history = self.get_history( trans, ids[0], False)
return self.display_by_username_and_slug( trans, history.user.username, history.slug )
- elif operation == "clone":
+ elif operation == "copy":
if not ids:
- message = "Select a history to clone"
+ message = "Select a history to copy"
return self.shared_list_grid( trans, status='error', message=message, **kwargs )
- # When cloning shared histories, only copy active datasets
- new_kwargs = { 'clone_choice' : 'active' }
- return self.clone( trans, ids, **new_kwargs )
+ # When copying shared histories, only copy active datasets
+ new_kwargs = { 'copy_choice' : 'active' }
+ return self.copy( trans, ids, **new_kwargs )
elif operation == 'unshare':
if not ids:
message = "Select a history to unshare"
@@ -957,7 +957,7 @@
def share( self, trans, id=None, email="", **kwd ):
# If a history contains both datasets that can be shared and others that cannot be shared with the desired user,
# then the entire history is shared, and the protected datasets will be visible, but inaccessible ( greyed out )
- # in the cloned history
+ # in the copyd history
params = util.Params( kwd )
user = trans.get_user()
# TODO: we have too many error messages floating around in here - we need
@@ -1270,15 +1270,16 @@
return trans.show_message( "<p>%s" % change_msg, refresh_frames=['history'] )
@web.expose
- @web.require_login( "clone shared Galaxy history" )
- def clone( self, trans, id=None, **kwd ):
- """Clone a list of histories"""
+ @web.require_login( "copy shared Galaxy history" )
+ def copy( self, trans, id=None, **kwd ):
+ """Copy one or more histories"""
params = util.Params( kwd )
# If clone_choice was not specified, display form passing along id
# argument
- clone_choice = params.get( 'clone_choice', None )
- if not clone_choice:
- return trans.fill_template( "/history/clone.mako", id_argument=id )
+ copy_choice = params.get( 'copy_choice', None )
+ if not copy_choice:
+ return trans.fill_template( "/history/copy.mako", id_argument=id )
+
# Extract histories for id argument, defaulting to current
if id is None:
histories = [ trans.history ]
@@ -1296,20 +1297,20 @@
if trans.sa_session.query( trans.app.model.HistoryUserShareAssociation ) \
.filter_by( user=user, history=history ) \
.count() == 0:
- return trans.show_error_message( "The history you are attempting to clone is not owned by you or shared with you. " )
+ return trans.show_error_message( "The history you are attempting to copy is not owned by you or shared with you. " )
owner = False
- name = "Clone of '%s'" % history.name
+ name = "Copy of '%s'" % history.name
if not owner:
name += " shared by '%s'" % history.user.email
- if clone_choice == 'activatable':
+ if copy_choice == 'activatable':
new_history = history.copy( name=name, target_user=user, activatable=True )
- elif clone_choice == 'active':
+ elif copy_choice == 'active':
name += " (active items only)"
new_history = history.copy( name=name, target_user=user )
if len( histories ) == 1:
- msg = 'Clone with name "<a href="%s" target="_top">%s</a>" is now included in your previously stored histories.' % ( url_for( controller="history", action="switch_to_history", hist_id=trans.security.encode_id( new_history.id ) ) , new_history.name )
+ msg = 'New history "<a href="%s" target="_top">%s</a>" has been created.' % ( url_for( controller="history", action="switch_to_history", hist_id=trans.security.encode_id( new_history.id ) ) , new_history.name )
else:
- msg = '%d cloned histories are now included in your previously stored histories.' % len( histories )
+ msg = 'Copied and created %d new histories.' % len( histories )
return trans.show_ok_message( msg )
@web.expose
@@ -1270,15 +1270,16 @@
params = util.Params( kwd )
- # If clone_choice was not specified, display form passing along id
+ # If copy_choice was not specified, display form passing along id
# argument
--
This is a commit notification from bitbucket.org. You are receiving
this because you have the service enabled, addressing the recipient of
this email.